--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'PWDCFG_CHALLENGE';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table PWDCFG_CHALLENGE
(
  ID            NUMBER(16) not null,
  PWDCFG        NUMBER(16) not null,
  LOCALIZATION  NUMBER(16) not null,
  STATUS        NUMBER(2),
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDCFG_CHALLENGE
  add constraint PWDCFG_CHALLENGE_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDCFG_CHALLENGE
  add constraint PWD_CHALL_PWDCFG_FK foreign key (PWDCFG)
  references PWDCFG (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDCFG_CHALLENGE
  add constraint PWD_CHALL_LOCALIZATION_FK foreign key (LOCALIZATION)
  references LOCALIZATION (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PWD_CHALL_PWDM_IDX on PWDCFG_CHALLENGE (PWDCFG)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PWD_CHALL_LOCALIZATION_IDX on PWDCFG_CHALLENGE (LOCALIZATION)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index PWD_CHALL_PWDM_IM_IDX on PWDCFG_CHALLENGE (PWDCFG, LOCALIZATION)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PWDCFG_CHALLENGE to AA;
grant select, insert, update, delete, references on PWDCFG_CHALLENGE to IDEAS;
grant select, insert, update, delete, references on PWDCFG_CHALLENGE to IDEAS_CONNECTOR;
grant select on PWDCFG_CHALLENGE to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'PWDCFG_CHALLENGE_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence PWDCFG_CHALLENGE_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PWDCFG_CHALLENGE_SEQ to AA;
grant select, alter on PWDCFG_CHALLENGE_SEQ to IDEAS;
grant select on PWDCFG_CHALLENGE_SEQ to IDEAS_CONNECTOR;
grant select on PWDCFG_CHALLENGE_SEQ to IDEAS_REPORT;
