--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'PWDMANAGEMENT_RESPONSE';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table PWDMANAGEMENT_RESPONSE
(
  ID               NUMBER(16) not null,
  PWDMANAGEMENT    NUMBER(16) not null,
  PWDCFG_CHALLENGE NUMBER(16) not null,
  RESPONSE         VARCHAR2(1024 CHAR) not null,
  STATUS           NUMBER(2),
  ATTR1            VARCHAR2(256 CHAR),
  ATTR2            VARCHAR2(256 CHAR),
  ATTR3            VARCHAR2(256 CHAR),
  ATTR4            VARCHAR2(256 CHAR),
  ATTR5            VARCHAR2(256 CHAR),
  CREATION_USER    VARCHAR2(128 CHAR),
  CREATION_DATE    DATE default SYSDATE,
  LAST_MOD_USER    VARCHAR2(128 CHAR),
  LAST_MOD_TIME    DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDMANAGEMENT_RESPONSE
  add constraint PWDMANAGEMENT_RESPONSE_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDMANAGEMENT_RESPONSE
  add constraint PWDM_RESP_PWDMAN_FK foreign key (PWDMANAGEMENT)
  references PWDMANAGEMENT (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDMANAGEMENT_RESPONSE
  add constraint PWDM_RESP_PWDCFG_CHALLENGE_FK foreign key (PWDCFG_CHALLENGE)
  references PWDCFG_CHALLENGE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PWDM_RESP_PWDMANAGEMENT_IDX on PWDMANAGEMENT_RESPONSE (PWDMANAGEMENT)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PWDM_RESP_PWDCFG_CHALLENGE_IDX on PWDMANAGEMENT_RESPONSE (PWDCFG_CHALLENGE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index PWDM_RESP_PWDM_LOC_IDX on PWDMANAGEMENT_RESPONSE (PWDMANAGEMENT, PWDCFG_CHALLENGE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on PWDMANAGEMENT_RESPONSE to AA;
grant select, insert, update, delete, references on PWDMANAGEMENT_RESPONSE to IDEAS;
grant select, insert, update, delete, references on PWDMANAGEMENT_RESPONSE to IDEAS_CONNECTOR;
grant select on PWDMANAGEMENT_RESPONSE to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'PWDMANAGEMENT_RESPONSE_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence PWDMANAGEMENT_RESPONSE_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select, alter on PWDMANAGEMENT_RESPONSE_SEQ to IDEAS;
grant select on PWDMANAGEMENT_RESPONSE_SEQ to IDEAS_CONNECTOR;
grant select on PWDMANAGEMENT_RESPONSE_SEQ to IDEAS_REPORT;
