--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'PWDMANAGEMENT_RESPONSE';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table PWDMANAGEMENT_RESPONSE
(
  ID               NUMERIC(16) not null,
  PWDMANAGEMENT    NUMERIC(16) not null,
  PWDCFG_CHALLENGE NUMERIC(16) not null,
  RESPONSE         VARCHAR(1024) not null,
  STATUS           NUMERIC(2),
  ATTR1            VARCHAR(256),
  ATTR2            VARCHAR(256),
  ATTR3            VARCHAR(256),
  ATTR4            VARCHAR(256),
  ATTR5            VARCHAR(256),
  CREATION_USER    VARCHAR(128),
  CREATION_DATE    DATE default CURRENT_DATE,
  LAST_MOD_USER    VARCHAR(128),
  LAST_MOD_TIME    DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE PWDMANAGEMENT_RESPONSE ADD
  CONSTRAINT PWDMANAGEMENT_RESPONSE_PK 
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDMANAGEMENT_RESPONSE
  add constraint PWDM_RESP_PWDMAN_FK foreign key (PWDMANAGEMENT)
  references PWDMANAGEMENT (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table PWDMANAGEMENT_RESPONSE
  add constraint PWDM_RESP_PWDCFG_CHALLENGE_FK foreign key (PWDCFG_CHALLENGE)
  references PWDCFG_CHALLENGE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PWDM_RESP_PWDMANAGEMENT_IDX on PWDMANAGEMENT_RESPONSE (PWDMANAGEMENT)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index PWDM_RESP_PWDCFG_CHALLENGE_IDX on PWDMANAGEMENT_RESPONSE (PWDCFG_CHALLENGE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index PWDM_RESP_PWDM_LOC_IDX on PWDMANAGEMENT_RESPONSE (PWDMANAGEMENT, PWDCFG_CHALLENGE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'PWDMANAGEMENT_RESPONSE';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE PWDMANAGEMENT_RESPONSE'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on PWDMANAGEMENT_RESPONSE to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PWDMANAGEMENT_RESPONSE to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on PWDMANAGEMENT_RESPONSE to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on PWDMANAGEMENT_RESPONSE to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'PWDMANAGEMENT_RESPONSE_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence PWDMANAGEMENT_RESPONSE_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence PWDMANAGEMENT_RESPONSE_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence PWDMANAGEMENT_RESPONSE_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence PWDMANAGEMENT_RESPONSE_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence PWDMANAGEMENT_RESPONSE_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
