--ADD A COLUMN TO A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'AGC_LANGUAGE';
  tab_col_name      varchar(30) := 'COUNTRY';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.columns t where t.tabschema = curr_user and lower ( t.tabname ) = lower ( tab_name ) and lower ( t.colname ) = lower ( tab_col_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'alter table AGC_LANGUAGE add COUNTRY VARCHAR(4)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

comment on column AGC_LANGUAGE.COUNTRY
  is 'identify the language in two lower char (ISO Country Code, ISO 3166)';


--DROP AN INDEX
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  idx_name          varchar(30) := 'AGC_LANGUAGE_LCODE_IDX';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.indexes t where t.indschema = curr_user and lower ( indname ) = lower ( idx_name );
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'drop index AGC_LANGUAGE_LCODE_IDX
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

--CREATE AN INDEX
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  idx_name          varchar(30) := 'AGC_LANGUAGE_LCODE_LCOU_IDX';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.indexes t where t.indschema = curr_user and lower ( indname ) = lower ( idx_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create unique index AGC_LANGUAGE_LCODE_LCOU_IDX on AGC_LANGUAGE (LOWER(CODE), LOWER(COUNTRY))
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'AGC_LANGUAGE';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE AGC_LANGUAGE'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

declare
  counter             numeric(16);  
begin
  select count(1) into counter from agc_language where lower ( code ) = lower ( 'PT' ) and country is null;
  if ( counter = 1 ) then
    update agc_language set country = 'BR' where lower ( code ) = lower ( 'PT' );
  end if;
end;
/
declare
  counter             numeric(16);  
begin
  select count(1) into counter from agc_language where lower ( code ) = lower ( 'PT' ) and lower ( country ) = lower ( 'BR' ) and name <> 'Brazilian';
  if ( counter = 1 ) then
   update agc_language set name = 'Brazilian' where lower ( code ) = lower ( 'PT' ) and lower ( country ) = lower ( 'BR' );
  end if;
end;
/

declare
  counter             numeric(16);  
begin
  select count(1) into counter from agc_language where lower ( code ) = lower ( 'ZH' ) and country is null;
  if ( counter = 1 ) then
    update agc_language set country = 'CN' where lower ( code ) = lower ( 'ZH' ) and country is null;
  end if;
end;
/
declare
  counter             numeric(16);  
begin
  select count(1) into counter from agc_language where lower ( code ) = lower ( 'ZH' ) and lower ( country ) = lower ( 'CN' );
  if ( counter = 1 ) then
    update agc_language set name = 'Simplified Chinese' where lower ( code ) = lower ( 'ZH' ) and lower ( country ) = lower ( 'CN' );
  end if;
end;
/

declare
  lan_id             numeric(16);
  lan_code_old       varchar(4) := '01';
  lan_code           varchar(4) := 'ZH';
  lan_country        varchar(4) := 'TW';
  lan_name           varchar(256) := 'Traditional Chinese';

  counter            numeric(16);
begin
  select count(1) into counter from agc_language t where  lower ( code ) = lower ( lan_code_old );
  if ( counter = 0 ) then
    select count(1) into counter from agc_language t
    where  lower ( code ) = lower ( lan_code ) and lower ( country ) = lower ( lan_country );
    if ( counter = 0 ) then
      select max ( id ) + 1 into lan_id from agc_language;
      insert into agc_language ( id, code, country, name )
      values ( lan_id, lan_code, lan_country, lan_name );
    end if;
  else 
    update agc_language set country = lan_country where lower ( code ) = lower ( lan_code_old );
    update agc_language set name = lan_name where lower ( code ) = lower ( lan_code_old );
    update agc_language set code = lan_code where lower ( code ) = lower ( lan_code_old );
  end if;
end;
/
commit;
