--RENAME A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name_src      varchar(30) := 'EMS_LOCALIZATION_TMP';
  tab_name_dest     varchar(30) := 'EMS_LOCALIZATION';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name_dest;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'rename ems_localization_tmp to ems_localization
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMS_LOCALIZATION ADD
  CONSTRAINT EMS_LOCALIZATION_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMS_I18N_MESSAGE ADD
  CONSTRAINT EMS_I18N_LOCALIZATION_FK
 FOREIGN KEY (LOCALIZATION)
 REFERENCES EMS_LOCALIZATION (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMS_TEMPLATE ADD
  CONSTRAINT EMS_TEMPLATE_BODY_FK
 FOREIGN KEY (BODY)
 REFERENCES EMS_LOCALIZATION (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE EMS_TEMPLATE ADD
  CONSTRAINT EMS_TEMPLATE_SUBJECT_FK
 FOREIGN KEY (SUBJECT)
 REFERENCES EMS_LOCALIZATION (ID)
    ON DELETE CASCADE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index EMS_LOCALIZATION_LNAME_IDX on EMS_LOCALIZATION (LOWER(CODE))
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'EMS_LOCALIZATION';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE EMS_LOCALIZATION'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'EMS_LOCALIZATION_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'CREATE SEQUENCE EMS_LOCALIZATION_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

--ALIGN A SEQUENCE
declare
  cur_pk       sys_refcursor;
  
  tab_name     varchar(128) := 'EMS_LOCALIZATION';
  pk_name      varchar(128) := 'ID';
  seq_name     varchar(128) := 'EMS_LOCALIZATION_SEQ';

  max_pk       numeric(16);
  seq_pk       numeric(16);

  counter      numeric(16);

  ddl_query    varchar(256);
begin
  max_pk := null;
  seq_pk := null;
  seq_name := tab_name||'_SEQ';

  ddl_query := 'select max ( ' || pk_name || ' ) from ' || tab_name;
  open cur_pk for ddl_query;
  fetch cur_pk into max_pk;
  close cur_pk;
    
  if( max_pk is null ) then
    max_pk := 1;
  end if;
    
  select count(1) into counter from syscat.sequences t where t.seqschema = current_user and t.seqname = seq_name;
    
  if ( counter = 1 ) then
    ddl_query := 'select nextval for '||seq_name||' from dual';
    open cur_pk for ddl_query;
    fetch cur_pk into seq_pk;
    close cur_pk;
      
    dbms_output.put_line(tab_name|| ' - '||pk_name||': ' || max_pk || ' - SEQ: ' || seq_pk);
      
    --il valore della sequence  minore del massimo della tabella
    if( max_pk > seq_pk  ) then
      loop
        open cur_pk for ddl_query;
        fetch cur_pk into seq_pk;
        close cur_pk;

        exit when seq_pk > max_pk;
      end loop;
    end if;--if(seq_pk < max_pk)
  else
    dbms_output.put_line(tab_name||' - '|| max_pk || ' - not found');
  end if;--if( counter = 1 )
    
end;
/
commit;

grant usage on sequence EMS_LOCALIZATION_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence EMS_LOCALIZATION_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage on sequence EMS_LOCALIZATION_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
