declare
  lan_id           numeric(16);
  lan_code         varchar(256) := 'EN';
  lan_country      varchar(256) := null;
  
  template_id      numeric(16);
  template_name    varchar(256) := 'ForgotPassword';
  template_value   varchar(256) := null;
  template_desc    varchar(512) := 'This is the template for Forgot Password scenario';
  
  subj_loc_id      numeric(16);
  subj_loc_name    varchar(256) := 'email.subject.';
  
  body_loc_id      numeric(16);
  body_loc_name    varchar(256) := 'email.body.';
  
  subj_mess_id     numeric(16);
  subj_mess        clob;

  body_mess_id     numeric(16);
  body_mess        clob;

  counter          numeric(16);
begin
  subj_mess :='Password Reset
';

  body_mess :='You have successfully requested a password reset for your account.
'||'If you did not request this reset, or believe you have received this email in error, please contact the helpdesk.
'||'The following password is valid for one login.
'||'After login, you will be prompted to change your password.
'||'';

  if ( lan_country is null ) then
    select t.id into lan_id from ems_language t where lower ( t.name ) = lower ( lan_code ) and t.country is null;
  else
    select t.id into lan_id from ems_language t where lower ( t.name ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;
  
  select count(1) into counter from ems_template t where lower ( t.name ) = lower ( template_name );
  if ( counter = 0 ) then
    select ems_template_seq.nextval into template_id from dual;
    insert into ems_template ( id, name, value, description, attr1, attr2, attr3, attr4, attr5 )
    values ( template_id, template_name, template_value, template_desc, null, null, null, null, null );
  else
    select t.id into template_id from ems_template t where lower ( t.name ) = lower ( template_name );
    update ems_template set value = template_value, description = template_desc where id = template_id;
  end if;
  
  subj_loc_name := subj_loc_name || template_id;
  select count(1) into counter from ems_localization t where lower ( t.code ) = lower ( subj_loc_name );
  if ( counter = 0 ) then
    select ems_localization_seq.nextval into subj_loc_id from dual;
    insert into ems_localization ( id, code, code_type )
    values ( subj_loc_id, subj_loc_name, 1 );
    
    update ems_template set subject = subj_loc_id where id = template_id;
  else
    select t.id into subj_loc_id from ems_localization t where lower ( t.code ) = lower ( subj_loc_name );

    select count(1) into counter from ems_template t where t.id = template_id and t.subject = subj_loc_id;
    if ( counter = 0 ) then
      update ems_template set subject = subj_loc_id where id = template_id;
    end if;
  end if;
  
  body_loc_name := body_loc_name || template_id;
  select count(1) into counter from ems_localization t where lower ( t.code ) = lower ( body_loc_name );
  if ( counter = 0 ) then
    select ems_localization_seq.nextval into body_loc_id from dual;
    insert into ems_localization ( id, code, code_type )
    values ( body_loc_id, body_loc_name, 1 );

    update ems_template set body = body_loc_id where id = template_id;
  else
    select t.id into body_loc_id from ems_localization t where lower ( t.code ) = lower ( body_loc_name );

    select count(1) into counter from ems_template t where t.id = template_id and t.body = body_loc_id;
    if ( counter = 0 ) then
      update ems_template set subject = body_loc_id where id = template_id;
    end if;
  end if;
  
  select count(1) into counter from ems_i18n_message t where t.language = lan_id and t.localization = subj_loc_id;
  if ( counter = 0 ) then
    select ems_i18n_message_seq.nextval into subj_mess_id from dual;
    insert into ems_i18n_message ( id, localization, language, message )
    values ( subj_mess_id, subj_loc_id, lan_id, subj_mess );
  else
    select t.id into subj_mess_id from ems_i18n_message t where t.language = lan_id and t.localization = subj_loc_id;
    update ems_i18n_message set message = subj_mess where id = subj_mess_id;
  end if;
  
  select count(1) into counter from ems_i18n_message t where t.language = lan_id and t.localization = body_loc_id;
  if ( counter = 0 ) then
    select ems_i18n_message_seq.nextval into subj_mess_id from dual;
    insert into ems_i18n_message ( id, localization, language, message )
    values ( subj_mess_id, body_loc_id, lan_id, body_mess );
  else
    select t.id into body_mess_id from ems_i18n_message t where t.language = lan_id and t.localization = body_loc_id;
    update ems_i18n_message set message = body_mess where id = body_mess_id;
  end if;
  
end;
/
commit;
