create table LANGUAGE
(
  ID            NUMBER(16) not null,
  CODE          VARCHAR2(3 CHAR) not null,
  COUNTRY       VARCHAR2(4 CHAR),
  NAME          VARCHAR2(256 CHAR) not null,
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
;
alter table LANGUAGE
  add constraint LANGUAGE_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics;

create unique index LANGUAGE_LCODE_COUNTRY_IDX on LANGUAGE (LOWER(CODE), LOWER(COUNTRY))
  tablespace &INDEX_TABLESPACE compute statistics;

create unique index LANGUAGE_LNAME_IDX on LANGUAGE (LOWER(NAME))
  tablespace &INDEX_TABLESPACE compute statistics;

comment on column LANGUAGE.CODE
  is 'identify the language in two lower char (ISO Language Code, ISO 639)';
comment on column LANGUAGE.COUNTRY
  is 'identify the language in two lower char (ISO Country Code, ISO 3166)';

grant select on LANGUAGE to AA;
grant select, insert, update, delete, references on LANGUAGE to IDEAS;
grant select, insert, update, delete, references on LANGUAGE to IDEAS_CONNECTOR;
grant select on LANGUAGE to IDEAS_REPORT;


create sequence LANGUAGE_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER;

grant select on LANGUAGE_SEQ to AA;
grant select, alter on LANGUAGE_SEQ to IDEAS;
grant select on LANGUAGE_SEQ to IDEAS_CONNECTOR;
grant select on LANGUAGE_SEQ to IDEAS_REPORT;


insert into language ( id, code, country, name )
values ( 1, 'IL', null, 'Ideas Language' );

insert into language ( id, code, country, name )
values ( 2, 'EN', null, 'English' );

insert into language ( id, code, country, name )
values ( 3, 'IT', null, 'Italian' );

insert into language ( id, code, country, name )
values ( 4, 'DE', null, 'German' );

insert into language ( id, code, country, name )
values ( 5, 'FR', null, 'French' );

insert into language ( id, code, country, name )
values ( 6, 'ES', null, 'Spanish' );

insert into language ( id, code, country, name )
values ( 7, 'PT', null, 'Portuguese' );

insert into language ( id, code, country, name )
values ( 8, 'ZH', null, 'Traditional Chinese' );

insert into language ( id, code, country, name )
values ( 9, 'JA', null, 'Japanese' );

insert into language ( id, code, country, name )
values ( 10, 'ZH', 'CN', 'Simplified Chinese' );

commit;
