create table LANGUAGE
(
  ID            NUMERIC(16) not null,
  CODE          VARCHAR(3) not null,
  COUNTRY       VARCHAR(4),
  NAME          VARCHAR(256) not null,
  ATTR1         VARCHAR(256),
  ATTR2         VARCHAR(256),
  ATTR3         VARCHAR(256),
  ATTR4         VARCHAR(256),
  ATTR5         VARCHAR(256),
  CREATION_USER VARCHAR(128),
  CREATION_DATE DATE default CURRENT_DATE,
  LAST_MOD_USER VARCHAR(128),
  LAST_MOD_TIME DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;
comment on column LANGUAGE.CODE
  is 'identify the language in two lower char (ISO Language Code, ISO 639)';
comment on column LANGUAGE.COUNTRY
  is 'identify the language in two lower char (ISO Country Code, ISO 3166)';

ALTER TABLE LANGUAGE ADD
  CONSTRAINT LANGUAGE_PK 
 PRIMARY KEY (ID);
CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE LANGUAGE' );

create unique index LANGUAGE_LCODE_COUNTRY_IDX on LANGUAGE (LOWER(CODE), LOWER(COUNTRY))
;

create unique index LANGUAGE_LNAME_IDX on LANGUAGE (LOWER(NAME))
;

grant select on LANGUAGE to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on LANGUAGE to &IDEAS_REPORT_SUPER_ADMIN_USER;


create sequence LANGUAGE_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER;

grant usage on sequence LANGUAGE_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence LANGUAGE_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;


insert into language ( id, code, country, name )
values ( 1, 'IL', null, 'Ideas Language' );

insert into language ( id, code, country, name )
values ( 2, 'EN', null, 'English' );

insert into language ( id, code, country, name )
values ( 3, 'IT', null, 'Italian' );

insert into language ( id, code, country, name )
values ( 4, 'DE', null, 'German' );

insert into language ( id, code, country, name )
values ( 5, 'FR', null, 'French' );

insert into language ( id, code, country, name )
values ( 6, 'ES', null, 'Spanish' );

insert into language ( id, code, country, name )
values ( 7, 'PT', null, 'Portuguese' );

insert into language ( id, code, country, name )
values ( 8, 'ZH', null, 'Traditional Chinese' );

insert into language ( id, code, country, name )
values ( 9, 'JA', null, 'Japanese' );

insert into language ( id, code, country, name )
values ( 10, 'ZH', 'CN', 'Simplified Chinese' );

commit;
