--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'LANGUAGE';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table LANGUAGE
(
  ID            NUMERIC(16) not null,
  CODE          VARCHAR(3) not null,
  COUNTRY       VARCHAR(4),
  NAME          VARCHAR(256) not null,
  ATTR1         VARCHAR(256),
  ATTR2         VARCHAR(256),
  ATTR3         VARCHAR(256),
  ATTR4         VARCHAR(256),
  ATTR5         VARCHAR(256),
  CREATION_USER VARCHAR(128),
  CREATION_DATE DATE default CURRENT_DATE,
  LAST_MOD_USER VARCHAR(128),
  LAST_MOD_TIME DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE LANGUAGE ADD
  CONSTRAINT LANGUAGE_PK
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index LANGUAGE_LCODE_COUNTRY_IDX on LANGUAGE (LOWER(CODE), LOWER(COUNTRY))
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index LANGUAGE_LNAME_IDX on LANGUAGE (LOWER(NAME))
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

comment on column LANGUAGE.CODE
  is 'identify the language in two lower char (ISO Language Code, ISO 639)';
comment on column LANGUAGE.COUNTRY
  is 'identify the language in two lower char (ISO Country Code, ISO 3166)';

grant select on LANGUAGE to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on LANGUAGE to &IDEAS_REPORT_SUPER_ADMIN_USER;

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'LANGUAGE_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence LANGUAGE_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence LANGUAGE_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence LANGUAGE_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;


declare
  lan_id       numeric(16) := 1;
  lan_code     varchar(256) := 'IL';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'Ideas Language';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 2;
  lan_code     varchar(256) := 'EN';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'English';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 3;
  lan_code     varchar(256) := 'IT';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'Italian';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 4;
  lan_code     varchar(256) := 'DE';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'German';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 5;
  lan_code     varchar(256) := 'FR';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'French';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 6;
  lan_code     varchar(256) := 'ES';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'Spanish';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 7;
  lan_code     varchar(256) := 'PT';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'Portuguese';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 8;
  lan_code     varchar(256) := 'ZH';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'Traditional Chinese';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 9;
  lan_code     varchar(256) := 'JA';
  lan_country  varchar(256) := null;
  lan_name     varchar(256) := 'Japanese';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       numeric(16) := 10;
  lan_code     varchar(256) := 'ZH';
  lan_country  varchar(256) := 'CN';
  lan_name     varchar(256) := 'Simplified Chinese';

  counter      numeric(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;
