--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'LANGUAGE';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table LANGUAGE
(
  ID            NUMBER(16) not null,
  CODE          VARCHAR2(3 CHAR) not null,
  COUNTRY       VARCHAR2(4 CHAR),
  NAME          VARCHAR2(256 CHAR) not null,
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table LANGUAGE
  add constraint LANGUAGE_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index LANGUAGE_LCODE_COUNTRY_IDX on LANGUAGE (LOWER(CODE), LOWER(COUNTRY))
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index LANGUAGE_LNAME_IDX on LANGUAGE (LOWER(NAME))
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

comment on column LANGUAGE.CODE
  is 'identify the language in two lower char (ISO Language Code, ISO 639)';
comment on column LANGUAGE.COUNTRY
  is 'identify the language in two lower char (ISO Country Code, ISO 3166)';

grant select on LANGUAGE to AA;
grant select, insert, update, delete, references on LANGUAGE to IDEAS;
grant select, insert, update, delete, references on LANGUAGE to IDEAS_CONNECTOR;
grant select on LANGUAGE to IDEAS_REPORT;

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'LANGUAGE_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence LANGUAGE_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on LANGUAGE_SEQ to AA;
grant select, alter on LANGUAGE_SEQ to IDEAS;
grant select on LANGUAGE_SEQ to IDEAS_CONNECTOR;
grant select on LANGUAGE_SEQ to IDEAS_REPORT;


declare
  lan_id       number(16) := 1;
  lan_code     varchar2(256) := 'IL';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'Ideas Language';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 2;
  lan_code     varchar2(256) := 'EN';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'English';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 3;
  lan_code     varchar2(256) := 'IT';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'Italian';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 4;
  lan_code     varchar2(256) := 'DE';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'German';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 5;
  lan_code     varchar2(256) := 'FR';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'French';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 6;
  lan_code     varchar2(256) := 'ES';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'Spanish';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 7;
  lan_code     varchar2(256) := 'PT';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'Portuguese';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 8;
  lan_code     varchar2(256) := 'ZH';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'Traditional Chinese';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 9;
  lan_code     varchar2(256) := 'JA';
  lan_country  varchar2(256) := null;
  lan_name     varchar2(256) := 'Japanese';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;

declare
  lan_id       number(16) := 10;
  lan_code     varchar2(256) := 'ZH';
  lan_country  varchar2(256) := 'CN';
  lan_name     varchar2(256) := 'Simplified Chinese';

  counter      number(16);
begin
  if ( lan_country is null ) then
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and t.country is null;
  else
    select count(1) into counter from LANGUAGE t where lower ( t.code ) = lower ( lan_code ) and lower ( t.country ) = lower ( lan_country );
  end if;

  if ( counter = 0 ) then
    select count(1) into counter from LANGUAGE t where t.id = lan_id;
  end if;

  if ( counter = 0 ) then
    insert into LANGUAGE ( id, code, country, name )
    values ( lan_id, lan_code, lan_country, lan_name );
  end if;
end;
/
commit;
