create table LANGUAGE_STATUS
(
  ID            NUMBER(16) not null,
  LANGUAGE      NUMBER(16) not null,
  IDEAS_MODULE  NUMBER(16) not null,
  STATUS        NUMBER(1) default 0,
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE;

alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics;

alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_LANGUAGE_FK foreign key (LANGUAGE)
  references LANGUAGE (ID);
alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade;

create index LANGUAGE_STATUS_IM_IDX on LANGUAGE_STATUS (IDEAS_MODULE)
  tablespace &INDEX_TABLESPACE compute statistics;

create index LANGUAGE_STATUS_LANGUAGE_IDX on LANGUAGE_STATUS (LANGUAGE)
  tablespace &INDEX_TABLESPACE compute statistics;
  
create unique index LANGUAGE_STATUS_LAN_IM_IDX on LANGUAGE_STATUS (LANGUAGE, IDEAS_MODULE)
  tablespace &INDEX_TABLESPACE compute statistics;

comment on column LANGUAGE_STATUS.STATUS
  is 'identify the language use status; 0=not-active, 1=active, 2=active and default';

grant select on LANGUAGE_STATUS to AA;
grant select, insert, update, delete, references on LANGUAGE_STATUS to IDEAS;
grant select, insert, update, delete, references on LANGUAGE_STATUS to IDEAS_CONNECTOR;
grant select on LANGUAGE_STATUS to IDEAS_REPORT;


create sequence LANGUAGE_STATUS_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER;

grant select on LANGUAGE_STATUS_SEQ to AA;
grant select, alter on LANGUAGE_STATUS_SEQ to IDEAS;
grant select on LANGUAGE_STATUS_SEQ to IDEAS_CONNECTOR;
grant select on LANGUAGE_STATUS_SEQ to IDEAS_REPORT;


declare
  cur_lan       sys_refcursor;
  lan_id        number(16);
  im_id         number(16);
  lan_status    number(16);
  lan_status_id number(16);

  counter       number(16);
begin
  open cur_lan for
    select lan.language, im.id as ideas_module, lan.status from ideas_module im,
    (
      select l.id as language, ll.status, 'AGC' as im_code from language l, agc_language ll
      where ll.status > 0 and lower ( l.code ) = lower ( ll.code )
      union
      select l.id as language, ll.status as status, 'AGC' as im_code from language l,
      (
        select 'ZH' as code, 'CN' as country, t.status as status from agc_language t
        where lower ( t.name ) = lower ( '01' ) and t.status > 0
      ) ll where lower ( l.code ) = lower ( ll.code ) and lower ( l.country ) = lower ( ll.country )
    ) lan where lower ( im.code ) = lower ( lan.im_code )
  ;
  loop
    fetch cur_lan into lan_id, im_id, lan_status;
    exit when cur_lan%NOTFOUND;
    
    select count(1) into counter from language_status t where t.language = lan_id and t.ideas_module = im_id;
    if ( counter = 0 ) then
      insert into language_status ( id, language, ideas_module, status )
      values ( language_status_seq.nextval, lan_id, im_id, lan_status );
    else
      select id into lan_status_id from language_status t where t.language = lan_id and t.ideas_module = im_id;
      update language_status set status = lan_status where id = lan_status_id;
    end if;
  end loop;
  close cur_lan;
end;
/
commit;
