create table LANGUAGE_STATUS
(
  ID            NUMERIC(16) not null,
  LANGUAGE      NUMERIC(16) not null,
  IDEAS_MODULE  NUMERIC(16) not null,
  STATUS        NUMERIC(1) default 0,
  ATTR1         VARCHAR(256),
  ATTR2         VARCHAR(256),
  ATTR3         VARCHAR(256),
  ATTR4         VARCHAR(256),
  ATTR5         VARCHAR(256),
  CREATION_USER VARCHAR(128),
  CREATION_DATE DATE default CURRENT_DATE,
  LAST_MOD_USER VARCHAR(128),
  LAST_MOD_TIME DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;

ALTER TABLE LANGUAGE_STATUS ADD
  CONSTRAINT LANGUAGE_STATUS_PK 
 PRIMARY KEY (ID);

alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_LANGUAGE_FK foreign key (LANGUAGE)
  references LANGUAGE (ID);
alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade;

create index LANGUAGE_STATUS_IM_IDX on LANGUAGE_STATUS (IDEAS_MODULE)
;

create index LANGUAGE_STATUS_LANGUAGE_IDX on LANGUAGE_STATUS (LANGUAGE)
;
  
create unique index LANGUAGE_STATUS_LAN_IM_IDX on LANGUAGE_STATUS (LANGUAGE, IDEAS_MODULE)
;

comment on column LANGUAGE_STATUS.STATUS
  is 'identify the language use status; 0=not-active, 1=active, 2=active and default';

CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE LANGUAGE_STATUS' );
grant select on LANGUAGE_STATUS to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE_STATUS to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE_STATUS to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on LANGUAGE_STATUS to &IDEAS_REPORT_SUPER_ADMIN_USER;


create sequence LANGUAGE_STATUS_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER;

grant usage on sequence LANGUAGE_STATUS_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_STATUS_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_STATUS_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence LANGUAGE_STATUS_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;


declare
  cur_lan       sys_refcursor;
  lan_id        NUMERIC(16);
  im_id         NUMERIC(16);
  lan_status    NUMERIC(16);
  lan_status_id NUMERIC(16);

  counter       NUMERIC(16);
begin
  open cur_lan for
    select lan.language, im.id as ideas_module, lan.status from ideas_module im,
    (
      select l.id as language, ll.status, 'AGC' as im_code from language l, agc_language ll
      where ll.status > 0 and lower ( l.code ) = lower ( ll.code )
      union
      select l.id as language, ll.status as status, 'AGC' as im_code from language l,
      (
        select 'ZH' as code, 'CN' as country, t.status as status from agc_language t
        where lower ( t.name ) = lower ( '01' ) and t.status > 0
      ) ll where lower ( l.code ) = lower ( ll.code ) and lower ( l.country ) = lower ( ll.country )
    ) lan where lower ( im.code ) = lower ( lan.im_code )
  ;
  loop
    fetch cur_lan into lan_id, im_id, lan_status;
    exit when cur_lan%NOTFOUND;
    
    select count(1) into counter from language_status t where t.language = lan_id and t.ideas_module = im_id;
    if ( counter = 0 ) then
      insert into language_status ( id, language, ideas_module, status )
      values ( language_status_seq.nextval, lan_id, im_id, lan_status );
    else
      select id into lan_status_id from language_status t where t.language = lan_id and t.ideas_module = im_id;
      update language_status set status = lan_status where id = lan_status_id;
    end if;
  end loop;
  close cur_lan;
end;
/
commit;
