--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'LANGUAGE_STATUS';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table LANGUAGE_STATUS
(
  ID            NUMERIC(16) not null,
  LANGUAGE      NUMERIC(16) not null,
  IDEAS_MODULE  NUMERIC(16) not null,
  STATUS        NUMERIC(1) default 0,
  ATTR1         VARCHAR(256),
  ATTR2         VARCHAR(256),
  ATTR3         VARCHAR(256),
  ATTR4         VARCHAR(256),
  ATTR5         VARCHAR(256),
  CREATION_USER VARCHAR(128),
  CREATION_DATE DATE default CURRENT_DATE,
  LAST_MOD_USER VARCHAR(128),
  LAST_MOD_TIME DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE LANGUAGE_STATUS ADD
  CONSTRAINT LANGUAGE_STATUS_PK 
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_LANGUAGE_FK foreign key (LANGUAGE)
  references LANGUAGE (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table LANGUAGE_STATUS
  add constraint LANGUAGE_STATUS_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index LANGUAGE_STATUS_IM_IDX on LANGUAGE_STATUS (IDEAS_MODULE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index LANGUAGE_STATUS_LANGUAGE_IDX on LANGUAGE_STATUS (LANGUAGE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index LANGUAGE_STATUS_LAN_IM_IDX on LANGUAGE_STATUS (LANGUAGE, IDEAS_MODULE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

comment on column LANGUAGE_STATUS.STATUS
  is 'identify the language use status; 0=not-active, 1=active, 2=active and default';
  
--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'LANGUAGE_STATUS';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE LANGUAGE_STATUS'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on LANGUAGE_STATUS to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE_STATUS to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LANGUAGE_STATUS to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on LANGUAGE_STATUS to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'LANGUAGE_STATUS_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence LANGUAGE_STATUS_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence LANGUAGE_STATUS_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_STATUS_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence LANGUAGE_STATUS_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence LANGUAGE_STATUS_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;


declare
  cur_lan       sys_refcursor;
  lan_id        numeric(16);
  im_id         numeric(16);
  lan_status    numeric(16);
  lan_status_id numeric(16);

  counter       numeric(16);
begin
  open cur_lan for
    select lan.language, im.id as ideas_module, lan.status from ideas_module im,
    (
      select l.id as language, ll.status, 'AGC' as im_code from language l, agc_language ll
      where ll.status > 0 and lower ( l.code ) = lower ( ll.code )
      union
      select l.id as language, ll.status as status, 'AGC' as im_code from language l,
      (
        select 'ZH' as code, 'CN' as country, t.status as status from agc_language t
        where lower ( t.name ) = lower ( '01' ) and t.status > 0
      ) ll where lower ( l.code ) = lower ( ll.code ) and lower ( l.country ) = lower ( ll.country )
    ) lan where lower ( im.code ) = lower ( lan.im_code )
  ;
  loop
    fetch cur_lan into lan_id, im_id, lan_status;
    exit when cur_lan%NOTFOUND;
    
    select count(1) into counter from language_status t where t.language = lan_id and t.ideas_module = im_id;
    if ( counter = 0 ) then
      insert into language_status ( id, language, ideas_module, status )
      values ( language_status_seq.nextval, lan_id, im_id, lan_status );
    else
      select id into lan_status_id from language_status t where t.language = lan_id and t.ideas_module = im_id;
      update language_status set status = lan_status where id = lan_status_id;
    end if;
  end loop;
  close cur_lan;
end;
/
commit;
