create table LOCALIZATION
(
  ID            NUMBER(16) not null,
  IDEAS_MODULE  NUMBER(16) not null,
  CODE          VARCHAR2(1024 CHAR) not null,
  CODE_TYPE     NUMBER(2) default 1 not null,
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
;
comment on column LOCALIZATION.CODE
  is 'identify the localization code used to map the message in i18nMessage table';
comment on column LOCALIZATION.CODE_TYPE
  is 'the type of code. 0=default; 1=custom';

alter table LOCALIZATION
  add constraint LOCALIZATION_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics;

alter table LOCALIZATION
  add constraint LOCALIZATION_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade;

create index LOCALIZATION_IM_IDX on LOCALIZATION (IDEAS_MODULE)
  tablespace &INDEX_TABLESPACE compute statistics;

create index LOCALIZATION_IM_CODE_TYPE_IDX on LOCALIZATION (IDEAS_MODULE, CODE_TYPE)
  tablespace &INDEX_TABLESPACE compute statistics;

create unique index LOCALIZATION_LNAME_IDX on LOCALIZATION (LOWER(CODE))
  tablespace &INDEX_TABLESPACE compute statistics;

grant select on LOCALIZATION to AA;
grant select, insert, update, delete, references on LOCALIZATION to IDEAS;
grant select, insert, update, delete, references on LOCALIZATION to IDEAS_CONNECTOR;
grant select on LOCALIZATION to IDEAS_REPORT;


create sequence LOCALIZATION_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER;

grant select on LOCALIZATION_SEQ to AA;
grant select, alter on LOCALIZATION_SEQ to IDEAS;
grant select on LOCALIZATION_SEQ to IDEAS_CONNECTOR;
grant select on LOCALIZATION_SEQ to IDEAS_REPORT;
