create table LOCALIZATION
(
  ID            NUMERIC(16) not null,
  IDEAS_MODULE  NUMERIC(16) not null,
  CODE          VARCHAR(1024) not null,
  CODE_TYPE     NUMERIC(2) default 1 not null,
  ATTR1         VARCHAR(256),
  ATTR2         VARCHAR(256),
  ATTR3         VARCHAR(256),
  ATTR4         VARCHAR(256),
  ATTR5         VARCHAR(256),
  CREATION_USER VARCHAR(128),
  CREATION_DATE DATE default CURRENT_DATE,
  LAST_MOD_USER VARCHAR(128),
  LAST_MOD_TIME DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
;
ALTER TABLE LOCALIZATION ADD
  CONSTRAINT LOCALIZATION_PK 
 PRIMARY KEY (ID);
alter table LOCALIZATION
  add constraint LOCALIZATION_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade;

create index LOCALIZATION_IM_IDX on LOCALIZATION (IDEAS_MODULE)
;

create index LOCALIZATION_IM_CODE_TYPE_IDX on LOCALIZATION (IDEAS_MODULE, CODE_TYPE)
;

create unique index LOCALIZATION_LNAME_IDX on LOCALIZATION (LOWER(CODE))
;

comment on column LOCALIZATION.CODE
  is 'identify the localization code used to map the message in i18nMessage table';
comment on column LOCALIZATION.CODE_TYPE
  is 'the type of code. 0=default; 1=custom';


CALL SYSPROC.ADMIN_CMD ( 'REORG TABLE LOCALIZATION' );

grant select on LOCALIZATION to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LOCALIZATION to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on LOCALIZATION to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on LOCALIZATION to &IDEAS_REPORT_SUPER_ADMIN_USER;


create sequence LOCALIZATION_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER;

grant usage on sequence LOCALIZATION_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence LOCALIZATION_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence LOCALIZATION_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence LOCALIZATION_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
