--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'LOCALIZATION';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table LOCALIZATION
(
  ID            NUMBER(16) not null,
  IDEAS_MODULE  NUMBER(16) not null,
  CODE          VARCHAR2(1024 CHAR) not null,
  CODE_TYPE     NUMBER(2) default 1 not null,
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table LOCALIZATION
  add constraint LOCALIZATION_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table LOCALIZATION
  add constraint LOCALIZATION_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index LOCALIZATION_IM_IDX on LOCALIZATION (IDEAS_MODULE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index LOCALIZATION_IM_CODE_TYPE_IDX on LOCALIZATION (IDEAS_MODULE, CODE_TYPE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index LOCALIZATION_LNAME_IDX on LOCALIZATION (LOWER(CODE))
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

comment on column LOCALIZATION.CODE
  is 'identify the localization code used to map the message in i18nMessage table';
comment on column LOCALIZATION.CODE_TYPE
  is 'the type of code. 0=default; 1=custom';

grant select on LOCALIZATION to AA;
grant select, insert, update, delete, references on LOCALIZATION to IDEAS;
grant select, insert, update, delete, references on LOCALIZATION to IDEAS_CONNECTOR;
grant select on LOCALIZATION to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'LOCALIZATION_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence LOCALIZATION_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on LOCALIZATION_SEQ to AA;
grant select, alter on LOCALIZATION_SEQ to IDEAS;
grant select on LOCALIZATION_SEQ to IDEAS_CONNECTOR;
grant select on LOCALIZATION_SEQ to IDEAS_REPORT;
