--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'I18N_MESSAGE';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table I18N_MESSAGE
(
  ID            NUMERIC(16) not null,
  IDEAS_MODULE  NUMERIC(16) not null,
  LOCALIZATION  NUMERIC(16) not null,
  LANGUAGE      NUMERIC(16) not null,
  MESSAGE       VARCHAR(4000),
  MESSAGE_LOB   CLOB,
  ATTR1         VARCHAR(256),
  ATTR2         VARCHAR(256),
  ATTR3         VARCHAR(256),
  ATTR4         VARCHAR(256),
  ATTR5         VARCHAR(256),
  CREATION_USER VARCHAR(128),
  CREATION_DATE DATE default CURRENT_DATE,
  LAST_MOD_USER VARCHAR(128),
  LAST_MOD_TIME DATE default CURRENT_DATE
)
IN &DATA_TABLESPACE
INDEX IN &INDEX_TABLESPACE
LONG IN &LOB_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE I18N_MESSAGE ADD
  CONSTRAINT I18N_MESSAGE_PK 
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table I18N_MESSAGE
  add constraint I18N_MESS_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table I18N_MESSAGE
  add constraint I18N_MESS_LANGUAGE_FK foreign key (LANGUAGE)
  references LANGUAGE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table I18N_MESSAGE
  add constraint I18N_MESS_LOCALIZATION_FK foreign key (LOCALIZATION)
  references LOCALIZATION (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index I18N_MESS_IM_IDX on I18N_MESSAGE (IDEAS_MODULE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );


  dml_def :=
'create index I18N_MESS_LANGUAGE_IDX on I18N_MESSAGE (LANGUAGE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );


  dml_def :=
'create index I18N_MESS_LOCALIZATION_IDX on I18N_MESSAGE (LOCALIZATION)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );


  dml_def :=
'create unique index I18N_MESS_IM_LOC_LANG_IDX on I18N_MESSAGE (IDEAS_MODULE, LOCALIZATION, LANGUAGE)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on


--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'I18N_MESSAGE';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE I18N_MESSAGE'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select on I18N_MESSAGE to &AA_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on I18N_MESSAGE to &IDEAS_SUPER_ADMIN_USER;
grant select, insert, update, delete, references on I18N_MESSAGE to &IDEAS_CONN_SUPER_ADMIN_USER;
grant select on I18N_MESSAGE to &IDEAS_REPORT_SUPER_ADMIN_USER;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'I18N_MESSAGE_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence I18N_MESSAGE_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage on sequence I18N_MESSAGE_SEQ to &AA_SUPER_ADMIN_USER;
grant usage, alter on sequence I18N_MESSAGE_SEQ to &IDEAS_SUPER_ADMIN_USER;
grant usage, alter on sequence I18N_MESSAGE_SEQ to &IDEAS_CONN_SUPER_ADMIN_USER;
grant usage on sequence I18N_MESSAGE_SEQ to &IDEAS_REPORT_SUPER_ADMIN_USER;
