--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'I18N_MESSAGE';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table I18N_MESSAGE
(
  ID            NUMBER(16) not null,
  IDEAS_MODULE  NUMBER(16) not null,
  LOCALIZATION  NUMBER(16) not null,
  LANGUAGE      NUMBER(16) not null,
  MESSAGE       VARCHAR2(4000 CHAR),
  MESSAGE_LOB   CLOB,
  ATTR1         VARCHAR2(256 CHAR),
  ATTR2         VARCHAR2(256 CHAR),
  ATTR3         VARCHAR2(256 CHAR),
  ATTR4         VARCHAR2(256 CHAR),
  ATTR5         VARCHAR2(256 CHAR),
  CREATION_USER VARCHAR2(128 CHAR),
  CREATION_DATE DATE default SYSDATE,
  LAST_MOD_USER VARCHAR2(128 CHAR),
  LAST_MOD_TIME DATE default SYSDATE
)
tablespace &DATA_TABLESPACE
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table I18N_MESSAGE
  add constraint I18N_MESSAGE_PK primary key (ID)
  using index 
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table I18N_MESSAGE
  add constraint I18N_MESS_IM_FK foreign key (IDEAS_MODULE)
  references IDEAS_MODULE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def := 'alter table I18N_MESSAGE
  add constraint I18N_MESS_LANGUAGE_FK foreign key (LANGUAGE)
  references LANGUAGE (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table I18N_MESSAGE
  add constraint I18N_MESS_LOCALIZATION_FK foreign key (LOCALIZATION)
  references LOCALIZATION (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index I18N_MESS_IM_IDX on I18N_MESSAGE (IDEAS_MODULE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index I18N_MESS_LANGUAGE_IDX on I18N_MESSAGE (LANGUAGE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create index I18N_MESS_LOCALIZATION_IDX on I18N_MESSAGE (LOCALIZATION)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'create unique index I18N_MESS_IM_LOC_LANG_IDX on I18N_MESSAGE (IDEAS_MODULE, LOCALIZATION, LANGUAGE)
  tablespace &INDEX_TABLESPACE compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on I18N_MESSAGE to AA;
grant select, insert, update, delete, references on I18N_MESSAGE to IDEAS;
grant select, insert, update, delete, references on I18N_MESSAGE to IDEAS_CONNECTOR;
grant select on I18N_MESSAGE to IDEAS_REPORT;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'I18N_MESSAGE_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def := 'create sequence I18N_MESSAGE_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select on I18N_MESSAGE_SEQ to AA;
grant select, alter on I18N_MESSAGE_SEQ to IDEAS;
grant select on I18N_MESSAGE_SEQ to IDEAS_CONNECTOR;
grant select on I18N_MESSAGE_SEQ to IDEAS_REPORT;
