declare
  rq_id            number(16);
  rq_name          varchar2(256) := 'Audit Trail - User assignments';
  rq_desc          varchar2(512) := 'Audit query by user. Extract role assignment and role removal sequence details';
  rqd              clob;

  counter          number(16);
begin
  rqd := 'select
'||'  t.event_date,
'||'  t.user_code,
'||'  t.user_name,
'||'  t.user_surname,
'||'  t.event_type,
'||'  t.ent_name,
'||'  t.application_name,
'||'  t.target_name,
'||'  t.action_type,
'||'  t.actor,
'||'  t.additional_data
'||'from
'||'(
'||'  select
'||'    t.event_date,
'||'    t.user_code,
'||'    t.user_name,
'||'    t.user_surname,
'||'    t.event_type,
'||'    t.ent_name,
'||'    app.name as application_name,
'||'    tg.name as target_name,
'||'    t.action_type,
'||'    t.actor,
'||'    t.additional_data
'||'  from
'||'    (
'||'      select
'||'        t.event_date,
'||'        p.id as user_id,
'||'        p.code as user_code,
'||'        p.name as user_name,
'||'        p.surname as user_surname,
'||'        t.event_type,
'||'        t.ent_name,
'||'        t.action_type,
'||'        t.actor,
'||'        t.additional_data
'||'      from
'||'      (
'||'        select t.event_date,
'||'          case
'||'            when instr( t.target_key_name, ''|'' ) = 0  then t.target_key_name
'||'            else substr ( t.target_key_name, 0, instr( t.target_key_name, ''|'' ) - 1)
'||'          end as pm_code,
'||'          case
'||'            when t.event_desc in ( ''Assigned Role to User'', ''Assigned Entitlement to User'' ) then ''Assigned''
'||'            when t.event_desc in ( ''Removed Role to User'', ''Removed Entitlement to User'' ) then ''Removed''
'||'          end as event_type,
'||'          --t.target_type,
'||'          t.obj1_key_name as ent_name,
'||'          case
'||'            when instr ( t.cod_operation, ''MR_'' ) = 1 then ''Rule Engine''
'||'            when instr ( t.cod_operation, ''PM_'' ) = 1 then ''IDEAS Console''
'||'            when instr ( t.cod_operation, ''AccessRequests'' ) = 1 then ''WorkFlow Request''
'||'            else t.cod_operation
'||'          end as action_type,
'||'          case
'||'            when instr ( t.cod_operation, ''AccessRequests'' ) = 1 then null
'||'            when instr ( t.cod_operation, ''MR_'' ) = 1 then null
'||'            else t.operator_code
'||'          end as actor,
'||'          case
'||'            when instr ( t.cod_operation, ''MR_'' ) = 1 then replace ( t.cod_operation, ''MR_'', '''' )
'||'            --when instr ( t.cod_operation, ''PM_'' ) = 1 then t.operator_code
'||'            when instr ( t.cod_operation, ''AccessRequests'' ) = 1 then ''Request ID: ''||replace ( t.cod_operation, ''AccessRequests'', '''' )
'||'          end as additional_data
'||'        from #servschema#.audit_log t where t.event_desc in ( ''Assigned Role to User'', ''Assigned Entitlement to User'', ''Removed Role to User'', ''Removed Entitlement to User'' )
'||'        and t.cod_operation not like ''RoleConstructor%''
'||'      ) t , #pmschema#.person p where p.code = t.pm_code
'||'  ) t
'||'  left join #pmschema#.entitlement e on lower ( e.name ) = lower ( t.ent_name )
'||'  left join #pmschema#.application app on app.id = e.application
'||'  left join #pmschema#.target tg on app.target = tg.id
'||'  union
'||'  select
'||'    erh.review_date as event_date,
'||'    p.code as user_code,
'||'    p.name as user_name,
'||'    p.surname as user_surname,
'||'    case
'||'      when erh.review_state = 0 then ''Not reviewed''
'||'      when erh.review_state = 1 then ''Approved''
'||'      when erh.review_state = 2 then ''Revoked''
'||'      when erh.review_state > 10 then ''Other''
'||'    end as event_type,
'||'    erh.entitlement_name,
'||'    app.name as application_name,
'||'    tg.name as target_name,
'||'    ''Review'' as action_type,
'||'    erh.cert_first_owner_code || '' - ''|| erh.cert_first_owner_surname || '' '' || erh.cert_first_owner_surname as actor,
'||'    ''Review date: '' || to_char( erh.review_date, ''#ideas_simpledate#'') as additional_data
'||'  from #pmschema#.employment_review_h erh
'||'  left join #pmschema#.person p on p.id = erh.person
'||'  left join #pmschema#.entitlement e on lower ( e.name ) = lower ( erh.entitlement_name )
'||'  left join #pmschema#.application app on app.id = e.application
'||'  left join #pmschema#.target tg on app.target = tg.id
'||') t
'||'where t.user_code = ''#user_code#''
'||'order by t.event_date
'||'';

  select count(1) into counter from r_query t where lower ( t.name ) = lower ( rq_name );
  if ( counter = 1 ) then
    select t.id into rq_id from r_query t where lower ( t.name ) = lower ( rq_name );

    update r_query_data set query = rqd where r_query = rq_id;
  end if;
  
end;
/

commit;
