--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'DASHBOARD_FIELD';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table DASHBOARD_FIELD
(
  ID              NUMERIC(16) not null,
  REPORT          NUMERIC(16) not null,
  GROUP_LEVEL     NUMERIC(16),
  R_QUERY_FIELD   NUMERIC(16),
  REPORT_FIELD    NUMERIC(16),
  LOCALIZATION    NUMERIC(16),
  POSITION        NUMERIC(16),
  GROUPING_BY     NUMERIC(1),
  FUNCTION_TYPE   NUMERIC(2),
  ORDER_BY        NUMERIC(16),
  ORDER_BY_CLAUSE VARCHAR(16),
  PARENT          NUMERIC(16)
)
IN IGA_REPORT_DATA
INDEX IN IGA_REPORT_INDX
LONG IN IGA_REPORT_BLOB
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'ALTER TABLE DASHBOARD_FIELD ADD
  CONSTRAINT DASHBOARD_FIELD_PK 
 PRIMARY KEY (ID)
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );
  
  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint LCODE_DASHBOARD_FIELD_FK foreign key (LOCALIZATION)
  references LOCALIZATION (ID) on delete set null
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_REPORT_FK foreign key (REPORT)
  references REPORT (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_R_Q_FIELD_FK foreign key (R_QUERY_FIELD)
  references R_QUERY_FIELD (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_REP_FIELD_FK foreign key (REPORT_FIELD)
  references REPORT_FIELD (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_PARENT_FK foreign key (PARENT)
  references DASHBOARD_FIELD (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

comment on column DASHBOARD_FIELD.GROUPING_BY
  is '0 - NOT A GROUP BY FIELD - 1: A GROUP BY FIELD';
comment on column DASHBOARD_FIELD.FUNCTION_TYPE
  is 'GROUPING FUNCTION';

--REORGANIZE A TABLE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  tab_name          varchar(30) := 'DASHBOARD_FIELD';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from sysibm.tables t where ( t.table_type = 'BASE TABLE' or t.table_type is null ) and lower ( t.table_schema ) = lower ( curr_user ) and t.table_name = tab_name;
  if ( counter = 0 ) then
    return;
  end if;

  dml_def :=
'CALL SYSPROC.ADMIN_CMD( ''REORG TABLE DASHBOARD_FIELD'' )
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant select, insert, update, delete, references on DASHBOARD_FIELD to REP;


--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar(30);
  
  seq_name          varchar(30) := 'DASHBOARD_FIELD_SEQ';
  dml_def           varchar(4000);
  
  counter           numeric(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from syscat.sequences t where lower ( t.seqschema ) = lower ( curr_user ) and t.seqtype <> 'I' and lower ( t.seqname ) = lower ( seq_name );
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence DASHBOARD_FIELD_SEQ
  AS NUMERIC(18)
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999
  NO CACHE
  NO CYCLE
  NO ORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
commit;
set serveroutput off
set verify on

grant usage, alter on sequence DASHBOARD_FIELD_SEQ to REP;
