--CREATE A TABLE AND ITS CONSTRAINTS
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  tab_name          varchar2(30) := 'DASHBOARD_FIELD';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_tables t where t.owner = curr_user and t.table_name = tab_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create table DASHBOARD_FIELD
(
  ID              NUMBER(16) not null,
  REPORT          NUMBER(16) not null,
  GROUP_LEVEL     NUMBER(16),
  R_QUERY_FIELD   NUMBER(16),
  REPORT_FIELD    NUMBER(16),
  LOCALIZATION    NUMBER(16),
  POSITION        NUMBER(16),
  GROUPING_BY     NUMBER(1),
  FUNCTION_TYPE   NUMBER(2),
  ORDER_BY        NUMBER(16),
  ORDER_BY_CLAUSE VARCHAR2(16 CHAR),
  PARENT          NUMBER(16)
)
tablespace IGA_REPORT_DATA
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_PK primary key (ID)
  using index 
  tablespace IGA_REPORT_INDX compute statistics
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint LCODE_DASHBOARD_FIELD_FK foreign key (LOCALIZATION)
  references LOCALIZATION (ID) on delete set null
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_REPORT_FK foreign key (REPORT)
  references REPORT (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_R_Q_FIELD_FK foreign key (R_QUERY_FIELD)
  references R_QUERY_FIELD (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_REP_FIELD_FK foreign key (REPORT_FIELD)
  references REPORT_FIELD (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

  dml_def :=
'alter table DASHBOARD_FIELD
  add constraint DASHBOARD_FIELD_PARENT_FK foreign key (PARENT)
  references DASHBOARD_FIELD (ID) on delete cascade
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select, insert, update, delete, references on DASHBOARD_FIELD to IDEAS_REPORT;

comment on column DASHBOARD_FIELD.GROUPING_BY
  is '0 - NOT A GROUP BY FIELD - 1: A GROUP BY FIELD';
comment on column DASHBOARD_FIELD.FUNCTION_TYPE
  is 'GROUPING FUNCTION';

--CREATE A SEQUENCE
set verify off
set serveroutput on
declare
  curr_user         varchar2(30);
  
  seq_name          varchar2(30) := 'DASHBOARD_FIELD_SEQ';
  dml_def           varchar2(4000);
  
  counter           number(16);
begin
  select trim ( user ) into curr_user from dual;
  select count(1) into counter from all_sequences t where t.sequence_owner = curr_user and t.sequence_name = seq_name;
  if ( counter = 1 ) then
    return;
  end if;

  dml_def :=
'create sequence DASHBOARD_FIELD_SEQ
  START WITH 100
  INCREMENT BY 1
  MINVALUE 100
  MAXVALUE 999999999999999999999999999
  NOCACHE
  NOCYCLE
  NOORDER
';

  if ( '&ECHO' = 'ON' ) then
    dbms_output.put_line ( dml_def );
  end if;
  execute immediate ( dml_def );

end;
/
set serveroutput off
set verify on

grant select, alter on DASHBOARD_FIELD_SEQ to IDEAS_REPORT;
